pub struct ParallelBuffered<St>(/* private fields */)
where
St: Stream,
St::Item: Future + Send + 'static,
<St::Item as Future>::Output: Send;Expand description
Given a Stream where every item is a Future, this stream buffers up
to a certain number of futures, runs them in parallel on separate tasks, and
returns the results of the futures in the order in which they appeared in
the input stream.
If any of the futures panics, all other futures and tasks are immediately cancelled and the panic gets returned immediately.
This stream is cancellation safe if the inner stream and generated futures are also cancellation safe. This means that dropping this stream will also cancel any outstanding tasks and drop the relevant futures/streams.
You can use ParallelBuffered::awaiting_completion to control
whether we wait for all tasks to fully terminate before this stream is
considered to have ended.
Implementations
Sourceimpl<St> ParallelBuffered<St>
impl<St> ParallelBuffered<St>
Sourcepub fn awaiting_completion(self, value: bool) -> Self
pub fn awaiting_completion(self, value: bool) -> Self
Whether to always await completion for the tasks from the
StreamParExt::parallel_buffered or
StreamParExt::parallel_buffered_with_token call, even when
one of the futures has panicked or been cancelled.