pub struct TryParallelBufferUnordered<St>(/* private fields */)
where
St: TryStream,
St::Ok: TryFuture<Error = St::Error> + Send + 'static,
St::Error: Send,
<St::Ok as TryFuture>::Ok: Send,
<St::Ok as TryFuture>::Error: Send;Expand description
Given a TryStream where every item is a TryFuture, this stream
buffers up to a certain number of futures, runs them in parallel on separate
tasks, and returns the results of the futures in completion order.
If any of the futures returns an error or panics, all other futures and tasks are immediately cancelled and the error/panic gets returned immediately.
This stream is cancellation safe if the inner stream and generated futures are also cancellation safe. This means that dropping this stream will also cancel any outstanding tasks and drop the relevant futures/streams.
You can use TryParallelBufferUnordered::awaiting_completion to control
whether we wait for all tasks to fully terminate before this stream is
considered to have ended.
Implementations
Sourceimpl<St> TryParallelBufferUnordered<St>
impl<St> TryParallelBufferUnordered<St>
Sourcepub fn awaiting_completion(self, value: bool) -> Self
pub fn awaiting_completion(self, value: bool) -> Self
Whether to always await completion for the tasks from the
TryStreamParExt::try_parallel_buffer_unordered or
TryStreamParExt::try_parallel_buffer_unordered_with_token call,
even when one of the futures has panicked or been cancelled.